import { Card, CardContent, CardFooter, CardHeader, CardTitle } from "@/components/ui/card";
import { Album, Gallery } from "@/generated/prisma";
import { TriangleAlert } from "lucide-react";
import Link from "next/link";

type AlbumWithGallery = Album & {
  gallery: Gallery | null;
};

export default function ListAlbums({ albums }: { albums: AlbumWithGallery[] }) {
  return (
    <div className="grid gap-6 sm:grid-cols-2 md:grid-cols-3 xl:grid-cols-4">
      {albums.map((album) => (
        <Link href={`/albums/edit/${album.id}`} key={album.id}>
          <Card className="overflow-hidden">
            <CardHeader>
              <CardTitle className="text-base truncate">{album.name}</CardTitle>
            </CardHeader>
            <CardContent>
              {album.description && <p className="text-sm text-muted-foreground">{album.description}</p>}
            </CardContent>
            <CardFooter>
              <div className="flex flex-col gap-4">
                {album.gallery ? (
                  <>Gallery: {album.gallery.name}</>
                ) : (
                  <div className="flex items-center text-destructive">
                    <TriangleAlert className="mr-2 h-4 w-4" />
                    No gallery
                  </div>
                )}
                <p className="text-sm text-muted-foreground">
                  Total images in this album: <span className="font-semibold">0</span>
                </p>
              </div>
            </CardFooter>
          </Card>
        </Link>
      ))}
    </div>
  );
}