"use client"

import { createGallery } from "@/actions/galleries/createGallery";
import { Button } from "@/components/ui/button";
import { Form, FormControl, FormDescription, FormField, FormItem, FormLabel, FormMessage } from "@/components/ui/form";
import { Input } from "@/components/ui/input";
import { gallerySchema } from "@/schemas/galleries/gallerySchema";
import { zodResolver } from "@hookform/resolvers/zod";
import { useRouter } from "next/navigation";
import { useForm } from "react-hook-form";
import { toast } from "sonner";
import * as z from "zod/v4";

export default function CreateGalleryForm() {
  const router = useRouter();
  const form = useForm<z.infer<typeof gallerySchema>>({
    resolver: zodResolver(gallerySchema),
    defaultValues: {
      name: "",
      slug: "",
      description: "",
    },
  })

  async function onSubmit(values: z.infer<typeof gallerySchema>) {
    var gallery = await createGallery(values)
    if (gallery) {
      toast.success("Gallery created")
      router.push(`/galleries`)
    }
  }

  return (
    <Form {...form}>
      <form onSubmit={form.handleSubmit(onSubmit)} className="space-y-8">
        <FormField
          control={form.control}
          name="name"
          render={({ field }) => (
            <FormItem>
              <FormLabel>Gallery name</FormLabel>
              <FormControl>
                <Input placeholder="Gallery name" {...field} />
              </FormControl>
              <FormDescription>
                This is your public display name.
              </FormDescription>
              <FormMessage />
            </FormItem>
          )}
        />
        <FormField
          control={form.control}
          name="slug"
          render={({ field }) => (
            <FormItem>
              <FormLabel>Gallery slug</FormLabel>
              <FormControl>
                <Input placeholder="Gallery slug" {...field} />
              </FormControl>
              <FormDescription>
                Will be used for the navigation.
              </FormDescription>
              <FormMessage />
            </FormItem>
          )}
        />
        <FormField
          control={form.control}
          name="description"
          render={({ field }) => (
            <FormItem>
              <FormLabel>Gallery description</FormLabel>
              <FormControl>
                <Input placeholder="Gallery description" {...field} />
              </FormControl>
              <FormDescription>
                Description of the gallery.
              </FormDescription>
              <FormMessage />
            </FormItem>
          )}
        />
        <div className="flex flex-col gap-4">
          <Button type="submit">Submit</Button>
          <Button type="reset" variant="secondary" onClick={() => router.back()}>Cancel</Button>
        </div>
      </form>
    </Form>
  );
}